@@ -10,6 +10,7 @@
 package org.gnu.gnome;
 
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.AccelGroup;
 import org.gnu.gtk.Container;
@@ -20,16 +21,40 @@ import org.gnu.gtk.ToolBar;
 import org.gnu.gtk.VBox;
 import org.gnu.gtk.Widget;
 import org.gnu.gtk.Window;
-import org.gnu.glib.Handle;
 
 /**
  * The App widget is the main window of a GNOME application. It is a container
  * widget that can hold a single child widget. It also includes facilities for
  * attaching menus, toolbars, a status bar, and widgets that can be docked.
+ *
+ * @deprecated This class is part of the java-gnome 2.x family of libraries,
+ *             which, due to their inefficiency and complexity, are no longer
+ *             being maintained and have been abandoned by the java-gnome
+ *             project. This class may have an equivalent
+ *             in java-gnome 4.0; have a look for
+ *             <code>org.gnome.gnome.App</code>.
  */
 
 public class App extends Window {
 
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
+     */
+    public static App getApp(Handle handle) {
+        if (handle == null)
+            return null;
+        
+        App app = (App) getGObjectFromHandle(handle);
+        if (app == null) {
+            app = new App(handle);
+        }
+        return app;
+    }
+
     /**
      * Instantiates a new Application window with the indicated name and title.
      * 
@@ -38,6 +63,10 @@ public class App extends Window {
      * @param title
      *            The title of the application window. The title can be null, in
      *            which case the window's title will not be set.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public App(String appname, String title) {
         super(gnome_app_new(appname, title == null ? null : title));
@@ -51,6 +80,10 @@ public class App extends Window {
      * Returns the dock.
      * 
      * @return The dock.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Widget getDock() {
         checkState();
@@ -62,6 +95,10 @@ public class App extends Window {
      * Main accelerator group for this window (hotkeys live here).
      * 
      * @return The accelorator group.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public AccelGroup getAccelGroup() {
         checkState();
@@ -72,6 +109,10 @@ public class App extends Window {
      * Returns the menu bar.
      * 
      * @return The MenuBar.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public MenuBar getMenuBar() {
         checkState();
@@ -81,6 +122,10 @@ public class App extends Window {
 
     /**
      * Returns the contents of the App.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Widget getContents() {
         checkState();
@@ -92,6 +137,10 @@ public class App extends Window {
      * Gets the name of the application.
      * 
      * @return The name of the application.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public String getName() {
         checkState();
@@ -102,6 +151,10 @@ public class App extends Window {
      * Gets the prefix for gnome-config, which is used to save the layout.
      * 
      * @return The prefix for gnome-config.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public String getPrefix() {
         checkState();
@@ -112,6 +165,10 @@ public class App extends Window {
      * Gets the status bar of the application windows.
      * 
      * @return The status bar.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public StatusBar getStatusBar() {
         checkState();
@@ -123,6 +180,10 @@ public class App extends Window {
      * <I>From gnome-app.h</I>The vbox widget that ties them.
      * 
      * @return The VBox.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public VBox getVBox() {
         checkState();
@@ -136,6 +197,10 @@ public class App extends Window {
      * 
      * @return True if the docking configuration is to be handled &
      *         automatically, else false.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public boolean layoutConfig() {
         checkState();
@@ -149,6 +214,10 @@ public class App extends Window {
      * @param enabled
      *            True if the docking configuration is to be handled
      *            automatically, else false.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void layoutConfig(boolean enabled) {
         checkState();
@@ -160,6 +229,10 @@ public class App extends Window {
      * 
      * @param contents
      *            The widget that contains the content of the window.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setContent(Widget contents) {
         checkState();
@@ -171,6 +244,10 @@ public class App extends Window {
      * 
      * @param menuBar
      *            The menu bar to be used for the window.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setMenuBar(MenuBar menuBar) {
         checkState();
@@ -182,6 +259,10 @@ public class App extends Window {
      * 
      * @param uiinfos
      *            An array of UIInfo objects that define the menu.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void createMenus(UIInfo[] uiinfos) {
         checkState();
@@ -201,6 +282,10 @@ public class App extends Window {
      *            The path to first item to remove.
      * @param num
      *            The number of items to remove.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void removeMenus(String path, int num) {
         checkState();
@@ -216,6 +301,10 @@ public class App extends Window {
      * @param uiinfos
      *            An array of UIInfo objects that describe the menu to be
      *            inserted.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void insertMenu(String path, UIInfo[] uiinfos) {
         checkState();
@@ -232,6 +321,10 @@ public class App extends Window {
      * 
      * @param toolBar
      *            The tool bar to be used for the window.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setToolBar(ToolBar toolBar) {
         checkState();
@@ -243,6 +336,10 @@ public class App extends Window {
      * 
      * @param uiinfos
      *            An array of UIInfo objects that define the toolbar.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void createToolBar(UIInfo[] uiinfos) {
         checkState();
@@ -259,6 +356,10 @@ public class App extends Window {
      * 
      * @param appBar
      *            The app bar to use for the window.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setStatusBar(AppBar appBar) {
         checkState();
@@ -270,6 +371,10 @@ public class App extends Window {
      * 
      * @param statusBar
      *            The status bar to use for the window.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setStatusBar(StatusBar statusBar) {
         checkState();
@@ -284,6 +389,10 @@ public class App extends Window {
      *            The app bar to use for the window.
      * @param container
      *            The container for the status bar.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setStatusBar(AppBar appBar, Container container) {
         checkState();
@@ -299,6 +408,10 @@ public class App extends Window {
      *            The status bar to use for the window.
      * @param container
      *            The container for the status bar.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void setStatusBar(StatusBar statusBar, Container container) {
         checkState();
@@ -314,6 +427,10 @@ public class App extends Window {
      * @param uiinfos
      *            An array of UIInfo objects that contain the menu items for
      *            which the hints will be created.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void installAppBarMenuHints(AppBar appBar, UIInfo[] uiinfos) {
         checkState();
@@ -332,6 +449,10 @@ public class App extends Window {
      * @param uiinfos
      *            An array of UIInfo objects that contain the menu items for
      *            which the hints will be created.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void installStatusBarMenuHints(StatusBar statusBar, UIInfo[] uiinfos) {
         checkState();
@@ -348,6 +469,10 @@ public class App extends Window {
      * @param uiinfos
      *            An array of UIInfo objects that contain the menu items for
      *            which the hints will be created.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void installMenuHints(UIInfo[] uiinfos) {
         checkState();
@@ -369,6 +494,10 @@ public class App extends Window {
      * @param accelGroup
      * @param underline
      * @param position
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void fillMenu(MenuShell menuShell, UIInfo[] uiinfos,
             AccelGroup accelGroup, boolean underline, int position) {
@@ -386,6 +515,10 @@ public class App extends Window {
      * @param toolbar
      * @param uiinfos
      * @param accelGroup
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void fillToolbar(ToolBar toolbar, UIInfo[] uiinfos,
             AccelGroup accelGroup) {
@@ -403,6 +536,10 @@ public class App extends Window {
      * @param path
      * @param start
      * @param numItems
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void removeMenuRange(String path, int start, int numItems) {
         checkState();
@@ -418,6 +555,10 @@ public class App extends Window {
      * @return The dialog created or null.
      * @deprecated
      * @see org.gnu.gtk.MessageDialog
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Widget message(String message) {
         Handle hndl = gnome_app_message(getHandle(), message);
@@ -436,6 +577,10 @@ public class App extends Window {
      * @param flash
      *            The message to flash.
      * @deprecated
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public void flash(String flash) {
         gnome_app_flash(getHandle(), flash);
@@ -450,6 +595,10 @@ public class App extends Window {
      * @return The dialog created or null.
      * @deprecated
      * @see org.gnu.gtk.MessageDialog
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Widget warning(String warning) {
         Handle hndl = gnome_app_warning(getHandle(), warning);
@@ -469,6 +618,10 @@ public class App extends Window {
      * @return The dialog created or null.
      * @deprecated
      * @see org.gnu.gtk.MessageDialog
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public Widget error(String error) {
         Handle hndl = gnome_app_error(getHandle(), error);
@@ -482,6 +635,10 @@ public class App extends Window {
 
     /**
      * Retrieve the runtime type used by the GLib library.
+     * @deprecated Superceeded by java-gnome 4.0; this method may or may not
+     *             exist in the new bindings but if it does, it will likely have 
+     *             a different name or signature in order that the presented API
+     *             is a more algorithmic mapping of the underlying native libraries.
      */
     public static Type getType() {
         return new Type(gnome_app_get_type());
