@@ -12,12 +12,13 @@
 #include <jg_jnu.h>
 #include <gtk_java.h>
 
+#include "org_gnu_gnome_App.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
   
-gchar * GnomeApp_get_name (GnomeApp * cptr) 
+static gchar * GnomeApp_get_name (GnomeApp * cptr) 
 {
     return cptr->name;
 }
@@ -32,7 +33,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_App_getName (JNIEnv *env, jclass cl
     return (*env)->NewStringUTF(env, (gchar*)GnomeApp_get_name (cptr_g));
 }
   
-gchar * GnomeApp_get_prefix (GnomeApp * cptr) 
+static gchar * GnomeApp_get_prefix (GnomeApp * cptr) 
 {
     return cptr->prefix;
 }
@@ -47,7 +48,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_App_getPrefix (JNIEnv *env, jclass
     return (*env)->NewStringUTF(env, (gchar*)GnomeApp_get_prefix (cptr_g));
 }
 
-GtkWidget * GnomeApp_get_dock (GnomeApp * cptr) 
+static GtkWidget * GnomeApp_get_dock (GnomeApp * cptr) 
 {
     return cptr->dock;
 }
@@ -62,7 +63,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getDock (JNIEnv *env, jclass cl
     return getGObjectHandle(env, G_OBJECT(GnomeApp_get_dock (cptr_g)));
 }
 
-GtkWidget * GnomeApp_get_statusbar (GnomeApp * cptr) 
+static GtkWidget * GnomeApp_get_statusbar (GnomeApp * cptr) 
 {
     return cptr->statusbar;
 }
@@ -77,7 +78,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getStatusbar (JNIEnv *env, jcla
     return getGObjectHandle(env, G_OBJECT(GnomeApp_get_statusbar (cptr_g)));
 }
 
-GtkWidget * GnomeApp_get_vbox (GnomeApp * cptr) 
+static GtkWidget * GnomeApp_get_vbox (GnomeApp * cptr) 
 {
     return cptr->vbox;
 }
@@ -92,7 +93,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getVbox (JNIEnv *env, jclass cl
     return getGObjectHandle(env, G_OBJECT(GnomeApp_get_vbox (cptr_g)));
 }
 
-GtkWidget * GnomeApp_get_menubar (GnomeApp * cptr) 
+static GtkWidget * GnomeApp_get_menubar (GnomeApp * cptr) 
 {
     return cptr->menubar;
 }
@@ -107,7 +108,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getMenubar (JNIEnv *env, jclass
     return getGObjectHandle(env, G_OBJECT(GnomeApp_get_menubar (cptr_g)));
 }
 
-GtkWidget * GnomeApp_get_contents (GnomeApp * cptr) 
+static GtkWidget * GnomeApp_get_contents (GnomeApp * cptr) 
 {
     return cptr->contents;
 }
@@ -122,7 +123,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getContents (JNIEnv *env, jclas
     return getGObjectHandle(env, G_OBJECT(GnomeApp_get_contents (cptr_g)));
 }
 
-GtkAccelGroup * GnomeApp_get_accel_group (GnomeApp * cptr) 
+static GtkAccelGroup * GnomeApp_get_accel_group (GnomeApp * cptr) 
 {
     return cptr->accel_group;
 }
@@ -137,7 +138,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_App_getAccelGroup (JNIEnv *env, jcl
     return getGObjectHandleAndRef(env, G_OBJECT(GnomeApp_get_accel_group (cptr_g)));
 }
 
-gboolean GnomeApp_get_enable_layout_config (GnomeApp * cptr) 
+static gboolean GnomeApp_get_enable_layout_config (GnomeApp * cptr) 
 {
     return cptr->enable_layout_config;
 }
