@@ -12,12 +12,15 @@
 #include <jg_jnu.h>
 #include <gtk_java.h>
 
+#include "org_gnu_gnome_CanvasItem.h"
+
 #ifdef __cplusplus
+
 extern "C" 
 {
 #endif
 
-GnomeCanvas * GnomeCanvasItem_get_canvas (GnomeCanvasItem * cptr) 
+static GnomeCanvas * GnomeCanvasItem_get_canvas (GnomeCanvasItem * cptr) 
 {
     return cptr->canvas;
 }
@@ -33,7 +36,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasItem_getCanvas (JNIEnv *env,
     return getGObjectHandle(env, G_OBJECT(GnomeCanvasItem_get_canvas (cptr_g)));
 }
 
-GnomeCanvasItem * GnomeCanvasItem_get_parent (GnomeCanvasItem * cptr) 
+static GnomeCanvasItem * GnomeCanvasItem_get_parent (GnomeCanvasItem * cptr) 
 {
     return cptr->parent;
 }
@@ -49,7 +52,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasItem_getParent (JNIEnv *env,
     return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasItem_get_parent (cptr_g)));
 }
 
-gdouble GnomeCanvasItem_get_x1 (GnomeCanvasItem * cptr) 
+static gdouble GnomeCanvasItem_get_x1 (GnomeCanvasItem * cptr) 
 {
     return cptr->x1;
 }
@@ -65,7 +68,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX1 (JNIEnv *env, jcla
     return (jdouble) (GnomeCanvasItem_get_x1 (cptr_g));
 }
 
-gdouble GnomeCanvasItem_get_y1 (GnomeCanvasItem * cptr) 
+static gdouble GnomeCanvasItem_get_y1 (GnomeCanvasItem * cptr) 
 {
     return cptr->y1;
 }
@@ -81,7 +84,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getY1 (JNIEnv *env, jcla
     return (jdouble) (GnomeCanvasItem_get_y1 (cptr_g));
 }
 
-gdouble GnomeCanvasItem_get_x2 (GnomeCanvasItem * cptr) 
+static gdouble GnomeCanvasItem_get_x2 (GnomeCanvasItem * cptr) 
 {
     return cptr->x2;
 }
@@ -97,7 +100,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasItem_getX2 (JNIEnv *env, jcla
     return (jdouble) (GnomeCanvasItem_get_x2 (cptr_g));
 }
 
-gdouble GnomeCanvasItem_get_y2 (GnomeCanvasItem * cptr) 
+static gdouble GnomeCanvasItem_get_y2 (GnomeCanvasItem * cptr) 
 {
     return cptr->y2;
 }
