@@ -9,7 +9,9 @@
 
 #include <jni.h>
 #include <libgnomecanvas/libgnomecanvas.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+
+#include "org_gnu_gnome_CanvasPixbuf.h"
 
 #ifdef __cplusplus
 extern "C" 
