@@ -8,15 +8,19 @@
  */
 
 #include <jni.h>
+#include <pango/pango.h>
 #include <libgnomecanvas/libgnomecanvas.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include <gtk_java.h>
+
+#include "org_gnu_gnome_CanvasText.h"
 
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-gchar * GnomeCanvasText_get_text (GnomeCanvasText * cptr) 
+static gchar * GnomeCanvasText_get_text (GnomeCanvasText * cptr) 
 {
     return cptr->text;
 }
@@ -33,7 +37,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_CanvasText_getText (JNIEnv *env, jc
     return (*env)->NewStringUTF(env, result_g);
 }
 
-void GnomeCanvasText_set_text (GnomeCanvasText * cptr, gchar * text) 
+static void GnomeCanvasText_set_text (GnomeCanvasText * cptr, gchar * text) 
 {
     cptr->text = text;
 }
@@ -42,7 +46,7 @@ void GnomeCanvasText_set_text (GnomeCanvasText * cptr, gchar * text)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setText
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setText (JNIEnv *env, jobject cptr, 
+  JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setText (JNIEnv *env, jclass cls, jobject cptr, 
     jstring text) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -51,7 +55,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setText (JNIEnv *env, jobje
     (*env)->ReleaseStringUTFChars(env, text, text_g);
 }
 
-gdouble GnomeCanvasText_get_x (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_x (GnomeCanvasText * cptr) 
 {
     return cptr->x;
 }
@@ -67,7 +71,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getX (JNIEnv *env, jclas
     return (jdouble) (GnomeCanvasText_get_x (cptr_g));
 }
 
-void GnomeCanvasText_set_x (GnomeCanvasText * cptr, gdouble x) 
+static void GnomeCanvasText_set_x (GnomeCanvasText * cptr, gdouble x) 
 {
     cptr->x = x;
 }
@@ -76,14 +80,14 @@ void GnomeCanvasText_set_x (GnomeCanvasText * cptr, gdouble x)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setX
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setX (JNIEnv *env, jobject cptr, jdouble x) 
+  JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setX (JNIEnv *env, jclass cls,  jobject cptr, jdouble x) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
     gdouble x_g = (gdouble) x;
     GnomeCanvasText_set_x (cptr_g, x_g);
 }
 
-gdouble GnomeCanvasText_get_y (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_y (GnomeCanvasText * cptr) 
 {
     return cptr->y;
 }
@@ -99,7 +103,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getY (JNIEnv *env, jclas
     return (jdouble) (GnomeCanvasText_get_y (cptr_g));
 }
 
-void GnomeCanvasText_set_y (GnomeCanvasText * cptr, gdouble y) 
+static void GnomeCanvasText_set_y (GnomeCanvasText * cptr, gdouble y) 
 {
     cptr->y = y;
 }
@@ -108,14 +112,14 @@ void GnomeCanvasText_set_y (GnomeCanvasText * cptr, gdouble y)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setY
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setY (JNIEnv *env, jobject cptr, jdouble y) 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setY (JNIEnv *env, jclass cls, jobject cptr, jdouble y) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
     gdouble y_g = (gdouble) y;
     GnomeCanvasText_set_y (cptr_g, y_g);
 }
 
-GtkAnchorType GnomeCanvasText_get_anchor (GnomeCanvasText * cptr) 
+static GtkAnchorType GnomeCanvasText_get_anchor (GnomeCanvasText * cptr) 
 {
     return cptr->anchor;
 }
@@ -131,7 +135,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getAnchor (JNIEnv *env, jcl
     return (jint) (GnomeCanvasText_get_anchor (cptr_g));
 }
 
-void GnomeCanvasText_set_anchor (GnomeCanvasText * cptr, GtkAnchorType anchor) 
+static void GnomeCanvasText_set_anchor (GnomeCanvasText * cptr, GtkAnchorType anchor) 
 {
     cptr->anchor = anchor;
 }
@@ -140,7 +144,7 @@ void GnomeCanvasText_set_anchor (GnomeCanvasText * cptr, GtkAnchorType anchor)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setAnchor
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAnchor (JNIEnv *env, jobject cptr, jint 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAnchor (JNIEnv *env, jclass cls, jobject cptr, jint 
     anchor) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -148,7 +152,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAnchor (JNIEnv *env, job
     GnomeCanvasText_set_anchor (cptr_g, anchor_g);
 }
 
-GtkJustification GnomeCanvasText_get_justification (GnomeCanvasText * cptr) 
+static GtkJustification GnomeCanvasText_get_justification (GnomeCanvasText * cptr) 
 {
     return cptr->justification;
 }
@@ -164,7 +168,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getJustification (JNIEnv *e
     return (jint) (GnomeCanvasText_get_justification (cptr_g));
 }
 
-void GnomeCanvasText_set_justification (GnomeCanvasText * cptr, GtkJustification justification) 
+static void GnomeCanvasText_set_justification (GnomeCanvasText * cptr, GtkJustification justification) 
 {
     cptr->justification = justification;
 }
@@ -173,7 +177,7 @@ void GnomeCanvasText_set_justification (GnomeCanvasText * cptr, GtkJustification
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setJustification
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setJustification (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setJustification (JNIEnv *env,jclass cls, jobject cptr, 
     jint justification) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -181,7 +185,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setJustification (JNIEnv *e
     GnomeCanvasText_set_justification (cptr_g, justification_g);
 }
 
-gdouble GnomeCanvasText_get_clip_width (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_clip_width (GnomeCanvasText * cptr) 
 {
     return cptr->clip_width;
 }
@@ -197,7 +201,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getClipWidth (JNIEnv *en
     return (jdouble) (GnomeCanvasText_get_clip_width (cptr_g));
 }
 
-void GnomeCanvasText_set_clip_width (GnomeCanvasText * cptr, gdouble clip_width) 
+static void GnomeCanvasText_set_clip_width (GnomeCanvasText * cptr, gdouble clip_width) 
 {
     cptr->clip_width = clip_width;
 }
@@ -206,7 +210,7 @@ void GnomeCanvasText_set_clip_width (GnomeCanvasText * cptr, gdouble clip_width)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setClipWidth
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipWidth (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipWidth (JNIEnv *env, jobject cptr, jclass cls,
     jdouble clip_width) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -214,7 +218,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipWidth (JNIEnv *env,
     GnomeCanvasText_set_clip_width (cptr_g, clip_width_g);
 }
 
-gdouble GnomeCanvasText_get_clip_height (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_clip_height (GnomeCanvasText * cptr) 
 {
     return cptr->clip_height;
 }
@@ -230,7 +234,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getClipHeight (JNIEnv *e
     return (jdouble) (GnomeCanvasText_get_clip_height (cptr_g));
 }
 
-void GnomeCanvasText_set_clip_height (GnomeCanvasText * cptr, gdouble clip_height) 
+static void GnomeCanvasText_set_clip_height (GnomeCanvasText * cptr, gdouble clip_height) 
 {
     cptr->clip_height = clip_height;
 }
@@ -239,7 +243,7 @@ void GnomeCanvasText_set_clip_height (GnomeCanvasText * cptr, gdouble clip_heigh
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setClipHeight
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipHeight (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipHeight (JNIEnv *env, jobject cptr, jclass cls,
     jdouble clip_height) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -247,7 +251,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClipHeight (JNIEnv *env,
     GnomeCanvasText_set_clip_height (cptr_g, clip_height_g);
 }
 
-glong GnomeCanvasText_get_pixel (GnomeCanvasText * cptr) 
+static glong GnomeCanvasText_get_pixel (GnomeCanvasText * cptr) 
 {
     return cptr->pixel;
 }
@@ -263,7 +267,7 @@ JNIEXPORT jlong JNICALL Java_org_gnu_gnome_CanvasText_getPixel (JNIEnv *env, jcl
     return (jlong) (GnomeCanvasText_get_pixel (cptr_g));
 }
 
-void GnomeCanvasText_set_pixel (GnomeCanvasText * cptr, glong pixel) 
+static void GnomeCanvasText_set_pixel (GnomeCanvasText * cptr, glong pixel) 
 {
     cptr->pixel = pixel;
 }
@@ -272,7 +276,7 @@ void GnomeCanvasText_set_pixel (GnomeCanvasText * cptr, glong pixel)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setPixel
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setPixel (JNIEnv *env, jobject cptr, jlong 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setPixel (JNIEnv *env, jclass cls, jobject cptr, jlong 
     pixel) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -280,7 +284,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setPixel (JNIEnv *env, jobj
     GnomeCanvasText_set_pixel (cptr_g, pixel_g);
 }
 
-GdkBitmap * GnomeCanvasText_get_stipple (GnomeCanvasText * cptr) 
+static GdkBitmap * GnomeCanvasText_get_stipple (GnomeCanvasText * cptr) 
 {
     return cptr->stipple;
 }
@@ -293,10 +297,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getStipple (JNIEnv *env,
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_stipple (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_stipple (cptr_g)));
 }
 
-void GnomeCanvasText_set_stipple (GnomeCanvasText * cptr, GdkBitmap * stipple) 
+static void GnomeCanvasText_set_stipple (GnomeCanvasText * cptr, GdkBitmap * stipple) 
 {
     cptr->stipple = stipple;
 }
@@ -305,7 +309,7 @@ void GnomeCanvasText_set_stipple (GnomeCanvasText * cptr, GdkBitmap * stipple)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setStipple
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStipple (JNIEnv *env, jobject cptr, jobject 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStipple (JNIEnv *env, jclass cls, jobject cptr, jobject 
     stipple) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -313,7 +317,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStipple (JNIEnv *env, jo
     GnomeCanvasText_set_stipple (cptr_g, stipple_g);
 }
 
-GdkGC * GnomeCanvasText_get_gc (GnomeCanvasText * cptr) 
+static GdkGC * GnomeCanvasText_get_gc (GnomeCanvasText * cptr) 
 {
     return cptr->gc;
 }
@@ -325,10 +329,10 @@ GdkGC * GnomeCanvasText_get_gc (GnomeCanvasText * cptr)
 JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getGc (JNIEnv *env, jclass cls, jobject cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_gc (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_gc (cptr_g)));
 }
 
-gint32 GnomeCanvasText_get_max_width (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_max_width (GnomeCanvasText * cptr) 
 {
     return cptr->max_width;
 }
@@ -344,7 +348,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getMaxWidth (JNIEnv *env, j
     return (jint) (GnomeCanvasText_get_max_width (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_height (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_height (GnomeCanvasText * cptr) 
 {
     return cptr->height;
 }
@@ -360,7 +364,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getHeight (JNIEnv *env, jcl
     return (jint) (GnomeCanvasText_get_height (cptr_g));
 }
 
-gboolean GnomeCanvasText_get_clip (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_clip (GnomeCanvasText * cptr) 
 {
     return cptr->clip;
 }
@@ -376,7 +380,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getClip (JNIEnv *env, j
     return (jboolean) (GnomeCanvasText_get_clip (cptr_g));
 }
 
-void GnomeCanvasText_set_clip (GnomeCanvasText * cptr, gboolean clip) 
+static void GnomeCanvasText_set_clip (GnomeCanvasText * cptr, gboolean clip) 
 {
     cptr->clip = clip;
 }
@@ -385,7 +389,7 @@ void GnomeCanvasText_set_clip (GnomeCanvasText * cptr, gboolean clip)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setClip
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClip (JNIEnv *env, jobject cptr, jboolean 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClip (JNIEnv *env, jclass cls, jobject cptr, jboolean 
     clip) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -393,7 +397,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setClip (JNIEnv *env, jobje
     GnomeCanvasText_set_clip (cptr_g, clip_g);
 }
 
-PangoFontDescription * GnomeCanvasText_get_font_desc (GnomeCanvasText * cptr) 
+static PangoFontDescription * GnomeCanvasText_get_font_desc (GnomeCanvasText * cptr) 
 {
     return cptr->font_desc;
 }
@@ -406,10 +410,13 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getFontDesc (JNIEnv *env
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_font_desc (cptr_g));
+    return getGBoxedHandle(env, GnomeCanvasText_get_font_desc (cptr_g),
+    		PANGO_TYPE_FONT_DESCRIPTION,
+    		(GBoxedCopyFunc) pango_font_description_copy,
+    		(GBoxedFreeFunc) pango_font_description_free);
 }
 
-void GnomeCanvasText_set_font_desc (GnomeCanvasText * cptr, PangoFontDescription * font_desc) 
+static void GnomeCanvasText_set_font_desc (GnomeCanvasText * cptr, PangoFontDescription * font_desc) 
 {
     cptr->font_desc = font_desc;
 }
@@ -418,7 +425,7 @@ void GnomeCanvasText_set_font_desc (GnomeCanvasText * cptr, PangoFontDescription
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setFontDesc
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setFontDesc (JNIEnv *env, jobject cptr, jobject 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setFontDesc (JNIEnv *env, jclass cls, jobject cptr, jobject 
     font_desc) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -426,7 +433,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setFontDesc (JNIEnv *env, j
     GnomeCanvasText_set_font_desc (cptr_g, font_desc_g);
 }
 
-PangoAttrList * GnomeCanvasText_get_attr_list (GnomeCanvasText * cptr) 
+static PangoAttrList * GnomeCanvasText_get_attr_list (GnomeCanvasText * cptr) 
 {
     return cptr->attr_list;
 }
@@ -439,10 +446,12 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getAttrList (JNIEnv *env
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_attr_list (cptr_g));
+    return getGBoxedHandle(env, GnomeCanvasText_get_attr_list (cptr_g),
+    		PANGO_TYPE_ATTR_LIST, (GBoxedCopyFunc) pango_attr_list_copy,
+    		(GBoxedFreeFunc) pango_attr_list_unref);
 }
 
-void GnomeCanvasText_set_attr_list (GnomeCanvasText * cptr, PangoAttrList * attr_list) 
+static void GnomeCanvasText_set_attr_list (GnomeCanvasText * cptr, PangoAttrList * attr_list) 
 {
     cptr->attr_list = attr_list;
 }
@@ -451,7 +460,7 @@ void GnomeCanvasText_set_attr_list (GnomeCanvasText * cptr, PangoAttrList * attr
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setAttrList
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAttrList (JNIEnv *env, jobject cptr, jobject 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAttrList (JNIEnv *env, jclass cls, jobject cptr, jobject 
     attr_list) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -459,7 +468,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setAttrList (JNIEnv *env, j
     GnomeCanvasText_set_attr_list (cptr_g, attr_list_g);
 }
 
-PangoUnderline GnomeCanvasText_get_underline (GnomeCanvasText * cptr) 
+static PangoUnderline GnomeCanvasText_get_underline (GnomeCanvasText * cptr) 
 {
     return cptr->underline;
 }
@@ -475,7 +484,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getUnderline (JNIEnv *env,
     return (jint) (GnomeCanvasText_get_underline (cptr_g));
 }
 
-void GnomeCanvasText_set_underline (GnomeCanvasText * cptr, PangoUnderline underline) 
+static void GnomeCanvasText_set_underline (GnomeCanvasText * cptr, PangoUnderline underline) 
 {
     cptr->underline = underline;
 }
@@ -484,7 +493,7 @@ void GnomeCanvasText_set_underline (GnomeCanvasText * cptr, PangoUnderline under
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setUnderline
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setUnderline (JNIEnv *env, jobject cptr, jint 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setUnderline (JNIEnv *env, jclass cls, jobject cptr, jint 
     underline) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -492,7 +501,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setUnderline (JNIEnv *env,
     GnomeCanvasText_set_underline (cptr_g, underline_g);
 }
 
-gboolean GnomeCanvasText_get_strikethrough (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_strikethrough (GnomeCanvasText * cptr) 
 {
     return cptr->strikethrough;
 }
@@ -508,7 +517,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getStrikethrough (JNIEn
     return (jboolean) (GnomeCanvasText_get_strikethrough (cptr_g));
 }
 
-void GnomeCanvasText_set_strikethrough (GnomeCanvasText * cptr, gboolean strikethrough) 
+static void GnomeCanvasText_set_strikethrough (GnomeCanvasText * cptr, gboolean strikethrough) 
 {
     cptr->strikethrough = strikethrough;
 }
@@ -517,7 +526,7 @@ void GnomeCanvasText_set_strikethrough (GnomeCanvasText * cptr, gboolean striket
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setStrikethrough
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStrikethrough (JNIEnv *env, jobject cptr, 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStrikethrough (JNIEnv *env, jclass cls, jobject cptr, 
     jboolean strikethrough) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -525,7 +534,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setStrikethrough (JNIEnv *e
     GnomeCanvasText_set_strikethrough (cptr_g, strikethrough_g);
 }
 
-gint32 GnomeCanvasText_get_rise (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_rise (GnomeCanvasText * cptr) 
 {
     return cptr->rise;
 }
@@ -541,7 +550,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getRise (JNIEnv *env, jclas
     return (jint) (GnomeCanvasText_get_rise (cptr_g));
 }
 
-void GnomeCanvasText_set_rise (GnomeCanvasText * cptr, gint32 rise) 
+static void GnomeCanvasText_set_rise (GnomeCanvasText * cptr, gint32 rise) 
 {
     cptr->rise = rise;
 }
@@ -550,14 +559,14 @@ void GnomeCanvasText_set_rise (GnomeCanvasText * cptr, gint32 rise)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setRise
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setRise (JNIEnv *env, jobject cptr, jint rise)
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setRise (JNIEnv *env, jclass cls, jobject cptr, jint rise)
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
     gint32 rise_g = (gint32) rise;
     GnomeCanvasText_set_rise (cptr_g, rise_g);
 }
 
-gdouble GnomeCanvasText_get_scale (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_scale (GnomeCanvasText * cptr) 
 {
     return cptr->scale;
 }
@@ -573,7 +582,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getScale (JNIEnv *env, j
     return (jdouble) (GnomeCanvasText_get_scale (cptr_g));
 }
 
-void GnomeCanvasText_set_scale (GnomeCanvasText * cptr, gdouble scale) 
+static void GnomeCanvasText_set_scale (GnomeCanvasText * cptr, gdouble scale) 
 {
     cptr->scale = scale;
 }
@@ -582,7 +591,7 @@ void GnomeCanvasText_set_scale (GnomeCanvasText * cptr, gdouble scale)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setScale
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setScale (JNIEnv *env, jobject cptr, jdouble 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setScale (JNIEnv *env, jclass cls, jobject cptr, jdouble 
     scale) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -590,7 +599,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setScale (JNIEnv *env, jobj
     GnomeCanvasText_set_scale (cptr_g, scale_g);
 }
 
-PangoLayout * GnomeCanvasText_get_layout (GnomeCanvasText * cptr) 
+static PangoLayout * GnomeCanvasText_get_layout (GnomeCanvasText * cptr) 
 {
     return cptr->layout;
 }
@@ -603,10 +612,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gnome_CanvasText_getLayout (JNIEnv *env,
     cptr) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GnomeCanvasText_get_layout (cptr_g));
+    return getGObjectHandleAndRef(env, G_OBJECT(GnomeCanvasText_get_layout (cptr_g)));
 }
 
-void GnomeCanvasText_set_layout (GnomeCanvasText * cptr, PangoLayout * layout) 
+static void GnomeCanvasText_set_layout (GnomeCanvasText * cptr, PangoLayout * layout) 
 {
     cptr->layout = layout;
 }
@@ -615,7 +624,7 @@ void GnomeCanvasText_set_layout (GnomeCanvasText * cptr, PangoLayout * layout)
  * Class:     org.gnu.gnome.CanvasText
  * Method:    setLayout
  */
-JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setLayout (JNIEnv *env, jobject cptr, jobject 
+JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setLayout (JNIEnv *env, jclass cls, jobject cptr, jobject 
     layout) 
 {
     GnomeCanvasText *cptr_g = (GnomeCanvasText *)getPointerFromHandle(env, cptr);
@@ -623,7 +632,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_CanvasText_setLayout (JNIEnv *env, job
     GnomeCanvasText_set_layout (cptr_g, layout_g);
 }
 
-gdouble GnomeCanvasText_get_xofs (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_xofs (GnomeCanvasText * cptr) 
 {
     return cptr->xofs;
 }
@@ -639,7 +648,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getXofs (JNIEnv *env, jc
     return (jdouble) (GnomeCanvasText_get_xofs (cptr_g));
 }
 
-gdouble GnomeCanvasText_get_yofs (GnomeCanvasText * cptr) 
+static gdouble GnomeCanvasText_get_yofs (GnomeCanvasText * cptr) 
 {
     return cptr->yofs;
 }
@@ -655,7 +664,7 @@ JNIEXPORT jdouble JNICALL Java_org_gnu_gnome_CanvasText_getYofs (JNIEnv *env, jc
     return (jdouble) (GnomeCanvasText_get_yofs (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_cx (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_cx (GnomeCanvasText * cptr) 
 {
     return cptr->cx;
 }
@@ -670,7 +679,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getCx (JNIEnv *env, jclass
     return (jint) (GnomeCanvasText_get_cx (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_cy (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_cy (GnomeCanvasText * cptr) 
 {
     return cptr->cy;
 }
@@ -685,7 +694,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getCy (JNIEnv *env, jclass
     return (jint) (GnomeCanvasText_get_cy (cptr_g));
 }
 
-gboolean GnomeCanvasText_get_underline_set (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_underline_set (GnomeCanvasText * cptr) 
 {
     return cptr->underline_set;
 }
@@ -701,7 +710,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getUnderlineSet (JNIEnv
     return (jboolean) (GnomeCanvasText_get_underline_set (cptr_g));
 }
 
-gboolean GnomeCanvasText_get_strike_set (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_strike_set (GnomeCanvasText * cptr) 
 {
     return cptr->strike_set;
 }
@@ -717,7 +726,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getStrikeSet (JNIEnv *e
     return (jboolean) (GnomeCanvasText_get_strike_set (cptr_g));
 }
 
-gboolean GnomeCanvasText_get_rise_set (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_rise_set (GnomeCanvasText * cptr) 
 {
     return cptr->rise_set;
 }
@@ -733,7 +742,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getRiseSet (JNIEnv *env
     return (jboolean) (GnomeCanvasText_get_rise_set (cptr_g));
 }
 
-gboolean GnomeCanvasText_get_scale_set (GnomeCanvasText * cptr) 
+static gboolean GnomeCanvasText_get_scale_set (GnomeCanvasText * cptr) 
 {
     return cptr->scale_set;
 }
@@ -749,7 +758,7 @@ JNIEXPORT jboolean JNICALL Java_org_gnu_gnome_CanvasText_getScaleSet (JNIEnv *en
     return (jboolean) (GnomeCanvasText_get_scale_set (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_clip_cx (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_clip_cx (GnomeCanvasText * cptr) 
 {
     return cptr->clip_cx;
 }
@@ -765,7 +774,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getClipCx (JNIEnv *env, jcl
     return (jint) (GnomeCanvasText_get_clip_cx (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_clip_cy (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_clip_cy (GnomeCanvasText * cptr) 
 {
     return cptr->clip_cy;
 }
@@ -781,7 +790,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getClipCy (JNIEnv *env, jcl
     return (jint) (GnomeCanvasText_get_clip_cy (cptr_g));
 }
 
-gint32 GnomeCanvasText_get_clip_cheight (GnomeCanvasText * cptr) 
+static gint32 GnomeCanvasText_get_clip_cheight (GnomeCanvasText * cptr) 
 {
     return cptr->clip_cheight;
 }
@@ -797,7 +806,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_CanvasText_getClipCheight (JNIEnv *env
     return (jint) (GnomeCanvasText_get_clip_cheight (cptr_g));
 }
 
-glong GnomeCanvasText_get_rgba (GnomeCanvasText * cptr) 
+static glong GnomeCanvasText_get_rgba (GnomeCanvasText * cptr) 
 {
     return cptr->rgba;
 }
