@@ -11,12 +11,14 @@
 #include <gnome.h>
 #include <jg_jnu.h>
 
+#include "org_gnu_gnome_ModuleInfo.h"
+
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-gchar * GnomeModuleInfo_get_name (GnomeModuleInfo * cptr) 
+static gchar * GnomeModuleInfo_get_name (GnomeModuleInfo * cptr) 
 {
     return (gchar *)cptr->name;
 }
@@ -33,7 +35,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_ModuleInfo_getName (JNIEnv *env, jc
     return (*env)->NewStringUTF(env, result_g);
 }
 
-gchar * GnomeModuleInfo_get_version (GnomeModuleInfo * cptr) 
+static gchar * GnomeModuleInfo_get_version (GnomeModuleInfo * cptr) 
 {
     return (gchar *)cptr->version;
 }
@@ -50,7 +52,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_ModuleInfo_getVersion (JNIEnv *env,
     return (*env)->NewStringUTF(env, result_g);
 }
 
-gchar * GnomeModuleInfo_get_description (GnomeModuleInfo * cptr) 
+static gchar * GnomeModuleInfo_get_description (GnomeModuleInfo * cptr) 
 {
     return (gchar *)cptr->description;
 }
