@@ -11,12 +11,14 @@
 #include <gnome.h>
 #include <jg_jnu.h>
 
+#include "org_gnu_gnome_UIBuilderData.h"
+
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-gpointer GnomeUIBuilderData_get_data (GnomeUIBuilderData * cptr) 
+static gpointer GnomeUIBuilderData_get_data (GnomeUIBuilderData * cptr) 
 {
     return cptr->data;
 }
@@ -25,14 +27,14 @@ gpointer GnomeUIBuilderData_get_data (GnomeUIBuilderData * cptr)
  * Class:     org.gnu.gnome.UIBuilderData
  * Method:    getData
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIBuilderData_getData (JNIEnv *env, jclass cls, jobject 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIBuilderData_getData (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
     GnomeUIBuilderData *cptr_g = (GnomeUIBuilderData *)getPointerFromHandle(env, cptr);
-    return (jint)GnomeUIBuilderData_get_data (cptr_g);
+    return getHandleFromPointer(env, GnomeUIBuilderData_get_data (cptr_g));
 }
 
-gboolean GnomeUIBuilderData_get_is_interp (GnomeUIBuilderData * cptr) 
+static gboolean GnomeUIBuilderData_get_is_interp (GnomeUIBuilderData * cptr) 
 {
     return cptr->is_interp;
 }
