@@ -11,6 +11,8 @@
 #include <gnome.h>
 #include <jg_jnu.h>
 
+#include "org_gnu_gnome_UIInfo.h"
+
 #ifdef __cplusplus
 extern "C" 
 {
@@ -149,7 +151,7 @@ JNIEXPORT void JNICALL Java_org_gnu_gnome_UIInfo_setSubmenuInfo
 }
                                                                                 
 
-GnomeUIInfoType GnomeUIInfo_get_type (GnomeUIInfo * cptr) 
+static GnomeUIInfoType GnomeUIInfo_get_type (GnomeUIInfo * cptr) 
 {
     return cptr->type;
 }
@@ -164,7 +166,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getType (JNIEnv *env, jclass cl
     return (jint) (GnomeUIInfo_get_type (cptr_g));
 }
 
-gchar * GnomeUIInfo_get_label (GnomeUIInfo * cptr) 
+static gchar * GnomeUIInfo_get_label (GnomeUIInfo * cptr) 
 {
     return (gchar *)cptr->label;
 }
@@ -180,7 +182,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_UIInfo_getLabel (JNIEnv *env, jclas
 	return (*env)->NewStringUTF(env, (gchar*)GnomeUIInfo_get_label (cptr_g));
 }
 
-gchar * GnomeUIInfo_get_hint (GnomeUIInfo * cptr) 
+static gchar * GnomeUIInfo_get_hint (GnomeUIInfo * cptr) 
 {
     return (gchar *)cptr->hint;
 }
@@ -196,7 +198,7 @@ JNIEXPORT jstring JNICALL Java_org_gnu_gnome_UIInfo_getHint (JNIEnv *env, jclass
 	return (*env)->NewStringUTF(env,(gchar*)GnomeUIInfo_get_hint (cptr_g));
 }
 
-gpointer GnomeUIInfo_get_moreinfo (GnomeUIInfo * cptr) 
+static gpointer GnomeUIInfo_get_moreinfo (GnomeUIInfo * cptr) 
 {
     return cptr->moreinfo;
 }
@@ -205,14 +207,14 @@ gpointer GnomeUIInfo_get_moreinfo (GnomeUIInfo * cptr)
  * Class:     org.gnu.gnome.UIInfo
  * Method:    getMoreinfo
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getMoreinfo (JNIEnv *env, jclass cls, jobject 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_getMoreinfo (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
     GnomeUIInfo *cptr_g = (GnomeUIInfo *)getPointerFromHandle(env, cptr);
-    return (jint)GnomeUIInfo_get_moreinfo (cptr_g);
+    return getHandleFromPointer(env, GnomeUIInfo_get_moreinfo (cptr_g));
 }
 
-gpointer GnomeUIInfo_get_user_data (GnomeUIInfo * cptr) 
+static gpointer GnomeUIInfo_get_user_data (GnomeUIInfo * cptr) 
 {
     return cptr->user_data;
 }
@@ -221,14 +223,14 @@ gpointer GnomeUIInfo_get_user_data (GnomeUIInfo * cptr)
  * Class:     org.gnu.gnome.UIInfo
  * Method:    getUserData
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getUserData (JNIEnv *env, jclass cls, jobject 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_getUserData (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
     GnomeUIInfo *cptr_g = (GnomeUIInfo *)getPointerFromHandle(env, cptr);
-    return (jint)GnomeUIInfo_get_user_data (cptr_g);
+    return getHandleFromPointer(env,GnomeUIInfo_get_user_data (cptr_g));
 }
 
-GnomeUIPixmapType GnomeUIInfo_get_pixmap_type (GnomeUIInfo * cptr) 
+static GnomeUIPixmapType GnomeUIInfo_get_pixmap_type (GnomeUIInfo * cptr) 
 {
     return cptr->pixmap_type;
 }
@@ -244,7 +246,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getPixmapType (JNIEnv *env, jcl
     return (jint) (GnomeUIInfo_get_pixmap_type (cptr_g));
 }
 
-gpointer GnomeUIInfo_get_pixmap_info (GnomeUIInfo * cptr) 
+static gpointer GnomeUIInfo_get_pixmap_info (GnomeUIInfo * cptr) 
 {
     return (gpointer)cptr->pixmap_info;
 }
@@ -253,14 +255,14 @@ gpointer GnomeUIInfo_get_pixmap_info (GnomeUIInfo * cptr)
  * Class:     org.gnu.gnome.UIInfo
  * Method:    getPixmapInfo
  */
-JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getPixmapInfo (JNIEnv *env, jclass cls, jobject 
+JNIEXPORT jobject JNICALL Java_org_gnu_gnome_UIInfo_getPixmapInfo (JNIEnv *env, jclass cls, jobject 
     cptr) 
 {
     GnomeUIInfo *cptr_g = (GnomeUIInfo *)getPointerFromHandle(env, cptr);
-    return (jint)GnomeUIInfo_get_pixmap_info (cptr_g);
+    return getPointerFromHandle(env, GnomeUIInfo_get_pixmap_info (cptr_g));
 }
 
-gint32 GnomeUIInfo_get_accelerator_key (GnomeUIInfo * cptr) 
+static gint32 GnomeUIInfo_get_accelerator_key (GnomeUIInfo * cptr) 
 {
     return cptr->accelerator_key;
 }
@@ -276,7 +278,7 @@ JNIEXPORT jint JNICALL Java_org_gnu_gnome_UIInfo_getAcceleratorKey (JNIEnv *env,
     return (jint) (GnomeUIInfo_get_accelerator_key (cptr_g));
 }
 
-GdkModifierType GnomeUIInfo_get_ac_mods (GnomeUIInfo * cptr) 
+static GdkModifierType GnomeUIInfo_get_ac_mods (GnomeUIInfo * cptr) 
 {
     return cptr->ac_mods;
 }
